==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/batchprocessimages/plugin/kipiplugin_batchprocessimages.desktop.cmake <==
[Desktop Entry]
Name=BatchProcessImages
Name[ast]=BatchProcessImages
Name[bg]=Пакетна обработка на изображения
Name[ca]=BatchProcessImages
Name[ca@valencia]=BatchProcessImages
Name[cs]=Dávkové zpracování obrázků
Name[da]=Batchbehandling af billeder
Name[de]=Bilder-Stapelverarbeitung
Name[el]=Ομαδική επεξεργασία εικόνων
Name[en_GB]=BatchProcessImages
Name[es]=Procesamiento en lote de imágenes
Name[et]=Piltide pakktöötlus
Name[eu]=Irudien batch prozesua
Name[fr]=Envoi d'images par courrier électronique
Name[ga]=BatchProcessImages
Name[gl]=BatchProcessImages
Name[hu]=Képek kötegelt feldolgozása
Name[is]=BatchProcessImages
Name[it]=Elaborazione di immagini non interattiva
Name[ja]=BatchProcessImages
Name[km]=BatchProcessImages
Name[lv]=BatchProcessImages
Name[nb]=Satsvis bildebehandling
Name[nds]=Bild-Stapelverarbeiden
Name[nl]=AfbeeldingenVerwerken
Name[pa]=BatchProcessImages
Name[pl]=WsadowePrzetwarzanieObrazów
Name[pt]=Processamento em Lote de Imagens
Name[pt_BR]=Processamento de imagens em lote
Name[ro]=Procesare de imagini în serie
Name[ru]=Пакетная обработка изображений
Name[sk]=Dávkové spracovanie obrázkov
Name[sl]=BatchProcessImages
Name[sq]=Procedim i Menjëhershëm i Imazheve
Name[sv]=Bakgrundsbehandling av bilder
Name[th]=ประมวลผลกลุ่มภาพ
Name[tr]=Çoklu Resim İşleme
Name[uk]=Пакетна обробка зображень
Name[x-test]=xxBatchProcessImagesxx
Name[zh_CN]=批处理图像
Name[zh_TW]=批次處理影像
Comment=KIPI Batch Processing Images Plugin
Comment[ast]=Complementu KIPI de procesamientu d'imáxenes por llotes
Comment[bg]=Приставка за KIPI за пакетна обработка
Comment[ca]=Connector KIPI per a processar imatges per lots
Comment[ca@valencia]=Connector KIPI per a processar imatges per lots
Comment[cs]=KIPI modul pro dávkové zpracování obrázků
Comment[da]=KIPI plugin til batchbehandling af billeder01000000 to 17999999
Comment[de]=Ein Werkzeug, zur Stapelverarbeitung von Bildern.
Comment[el]=Πρόσθετο του KIPI για την ομαδική επεξεργασία εικόνων
Comment[en_GB]=KIPI Batch Processing Images Plugin
Comment[es]=Complemento de KIPI para procesar imágenes por lotes
Comment[et]=KIPI piltide pakktöötluse plugin
Comment[eu]=KIPIren plugina irudien batch prozesurako
Comment[fi]=Eräajokäsittely
Comment[fr]=Module externe KIPI envoi d'images par courrier électronique
Comment[gl]=Un engadido de KIPI para procesar lotes de imaxes
Comment[hu]=KIPI képek kötegelt feldolgozása bővítmény
Comment[is]=KIPI íforrit til magnvinnslu mynda
Comment[it]=Estensione di elaborazione di immagini non interattiva di KIPI
Comment[ja]=画像を一括処理する Kipi プラグイン
Comment[km]=កម្មវិធី​ជំនួយ​រូបភាព​ដំណើរការ​​ជា​បាច់​របស់​ KIPI
Comment[lv]=KIPI spraudnis attēlu masveida apstrādei
Comment[nb]=KIPI programtillegg for satsvis bildebehandling
Comment[nds]=KIPI-Moduul, dat Billerstapels verarbeiden deit
Comment[nl]=KIPI-plugin voor het bulkverwerken van afbeeldingen
Comment[pa]=KIPI ਬੈਚ ਪਰੋਸੈਸਿੰਗ ਚਿੱਤਰ ਪਲੱਗਇਨ
Comment[pl]=Wtyczka wsadowego przetwarzania obrazów dla KIPI
Comment[pt]='Plugin' de Processamento de Imagens em Lote do KIPI
Comment[pt_BR]=Plugin do KIPI para processamento de imagens em lote
Comment[ro]=Extensie KIPI pentru procesarea de imagini în serie
Comment[ru]=Модуль KIPI для пакетной обработки изображений
Comment[sk]=KIPI zásuvný modul pre dávkové spracovanie obrázkov
Comment[sl]=Vstavek KIPI za paketno obdelovanje slik
Comment[sq]=Plugin Për Procedimin e Menjëhershëm të Imazheve KIPI
Comment[sv]=KIPI-insticksprogram för bakgrundsbehandling av bilder
Comment[th]=ส่วนเสริมของ KIPI เพื่อใช้ในการประมวลผลกลุ่มภาพ
Comment[tr]=KIPI Çoklu Resim İşleme Eklentisi
Comment[uk]=Додаток KIPI для пакетної обробки зображень
Comment[x-test]=xxKIPI Batch Processing Images Pluginxx
Comment[zh_CN]=KIPI 批处理图像插件
Comment[zh_TW]=KIPI 批次處理影像外掛程式
Icon=borderimages
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_batchprocessimages
X-KIPI-PluginCategories=Batch
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam_3.4.0.orig.tar.bz2: digikam-3.4.0/extra/kipi-plugins/batchprocessimages/plugin/kipiplugin_batchprocessimages.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=BatchProcessImages
Name=BatchProcessImages
Name[ast]=BatchProcessImages
Name[bg]=Пакетна обработка на изображения
Name[bs]=BatchProcessImages
Name[ca]=BatchProcessImages
Name[ca@valencia]=BatchProcessImages
Name[cs]=Dávkové zpracování obrázků
Name[da]=Batchbehandling af billeder
Name[de]=Bilder-Stapelverarbeitung
Name[el]=Ομαδική επεξεργασία εικόνων
Name[en_GB]=BatchProcessImages
Name[es]=Procesamiento en lote de imágenes
Name[et]=Piltide pakktöötlus
Name[eu]=Irudien batch prozesua
Name[fr]=Envoi d'images par courrier électronique
Name[ga]=BatchProcessImages
Name[gl]=BatchProcessImages
Name[hu]=Képek kötegelt feldolgozása
Name[is]=BatchProcessImages
Name[it]=Elaborazione di immagini non interattiva
Name[ja]=BatchProcessImages
Name[km]=BatchProcessImages
Name[lv]=BatchProcessImages
Name[nb]=Satsvis bildebehandling
Name[nds]=Bild-Stapelverarbeiden
Name[nl]=AfbeeldingenVerwerken
Name[pa]=BatchProcessImages
Name[pl]=WsadowePrzetwarzanieObrazów
Name[pt]=Processamento em Lote de Imagens
Name[pt_BR]=Processamento de imagens em lote
Name[ro]=Procesare de imagini în serie
Name[ru]=Пакетная обработка изображений
Name[sk]=Dávkové spracovanie obrázkov
Name[sl]=BatchProcessImages
Name[sq]=Procedim i Menjëhershëm i Imazheve
Name[sv]=Bakgrundsbehandling av bilder
Name[th]=ประมวลผลกลุ่มภาพ
Name[tr]=Çoklu Resim İşleme
Name[uk]=Пакетна обробка зображень
Name[x-test]=xxBatchProcessImagesxx
Name[zh_CN]=批处理图像
Name[zh_TW]=批次處理影像
Comment=KIPI Batch Processing Images Plugin
Comment[ast]=Complementu KIPI de procesamientu d'imáxenes por llotes
Comment[bg]=Приставка за KIPI за пакетна обработка
Comment[bs]=KIPI dodatak za skupnu obradu slika
Comment[ca]=Connector KIPI per a processar imatges per lots
Comment[ca@valencia]=Connector KIPI per a processar imatges per lots
Comment[cs]=KIPI modul pro dávkové zpracování obrázků
Comment[da]=KIPI plugin til batchbehandling af billeder01000000 to 17999999
Comment[de]=Ein Werkzeug, zur Stapelverarbeitung von Bildern.
Comment[el]=Πρόσθετο του KIPI για την ομαδική επεξεργασία εικόνων
Comment[en_GB]=KIPI Batch Processing Images Plugin
Comment[es]=Complemento de KIPI para procesar imágenes por lotes
Comment[et]=KIPI piltide pakktöötluse plugin
Comment[eu]=KIPIren plugina irudien batch prozesurako
Comment[fi]=Eräajokäsittely
Comment[fr]=Module externe KIPI d'envoi d'images par courrier électronique
Comment[gl]=Un engadido de KIPI para procesar lotes de imaxes
Comment[hu]=KIPI képek kötegelt feldolgozása bővítmény
Comment[is]=KIPI íforrit til magnvinnslu mynda
Comment[it]=Estensione di elaborazione di immagini non interattiva di KIPI
Comment[ja]=画像を一括処理する Kipi プラグイン
Comment[km]=កម្មវិធី​ជំនួយ​រូបភាព​ដំណើរការ​​ជា​បាច់​របស់​ KIPI
Comment[lv]=KIPI spraudnis attēlu masveida apstrādei
Comment[nb]=KIPI programtillegg for satsvis bildebehandling
Comment[nds]=KIPI-Moduul, dat Billerstapels verarbeiden deit
Comment[nl]=KIPI-plugin voor het bulkverwerken van afbeeldingen
Comment[pa]=KIPI ਬੈਚ ਪਰੋਸੈਸਿੰਗ ਚਿੱਤਰ ਪਲੱਗਇਨ
Comment[pl]=Wtyczka wsadowego przetwarzania obrazów dla KIPI
Comment[pt]='Plugin' de Processamento de Imagens em Lote do KIPI
Comment[pt_BR]=Plugin do KIPI para processamento de imagens em lote
Comment[ro]=Extensie KIPI pentru procesarea de imagini în serie
Comment[ru]=Модуль KIPI для пакетной обработки изображений
Comment[sk]=KIPI zásuvný modul pre dávkové spracovanie obrázkov
Comment[sl]=Vstavek KIPI za paketno obdelovanje slik
Comment[sq]=Plugin Për Procedimin e Menjëhershëm të Imazheve KIPI
Comment[sv]=KIPI-insticksprogram för bakgrundsbehandling av bilder
Comment[th]=ส่วนเสริมของ KIPI เพื่อใช้ในการประมวลผลกลุ่มภาพ
Comment[tr]=KIPI Çoklu Resim İşleme Eklentisi
Comment[uk]=Додаток KIPI для пакетної обробки зображень
Comment[x-test]=xxKIPI Batch Processing Images Pluginxx
Comment[zh_CN]=KIPI 批处理图像插件
Comment[zh_TW]=KIPI 批次處理影像外掛程式
Icon=borderimages
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_batchprocessimages
X-KIPI-PluginCategories=Batch
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
